@@ -38,9 +38,17 @@ test_that("Setting custom permutation in gips constructor works", {
   expect_identical(custom_perm1, g1[[1]])
 
   expect_identical(gips_perm(custom_perm2, ncol(S)), g2[[1]])
+
+  # gips as the `perm` parameter
+  g3 <- gips(
+    S, number_of_observations,
+    was_mean_estimated = FALSE, perm = g2
+  )
+
+  expect_equal(g2, g3)
 })
 
-test_that("new_gips works or throws an erron on wrong arguments", {
+test_that("new_gips() works or throws an erron on wrong arguments", {
   expect_silent(new_gips(
     list(gips_perm("(1,2)(3,4,5,6)", 6)),
     S, number_of_observations, 3, diag(nrow = ncol(S)), FALSE, NULL
@@ -116,29 +124,31 @@ test_that("Properly validate the gips class with no optimization or after a sing
     optimizer = "HC", return_probabilities = FALSE
   )
 
-  g_BF <- find_MAP(gips(
-    matrix(c(
-      1, 0.5, 0.5,
-      0.5, 1, 0.5,
-      0.5, 0.5, 1
-    ), nrow = 3),
-    number_of_observations,
-    was_mean_estimated = FALSE
-  ),
-  optimizer = "BF", show_progress_bar = FALSE
+  g_BF <- find_MAP(
+    gips(
+      matrix(c(
+        1, 0.5, 0.5,
+        0.5, 1, 0.5,
+        0.5, 0.5, 1
+      ), nrow = 3),
+      number_of_observations,
+      was_mean_estimated = FALSE
+    ),
+    optimizer = "BF", show_progress_bar = FALSE
   )
 
-  g_BF_prob <- find_MAP(gips(
-    matrix(c(
-      1, 0.5, 0.5,
-      0.5, 1, 0.5,
-      0.5, 0.5, 1
-    ), nrow = 3),
-    number_of_observations,
-    was_mean_estimated = FALSE
-  ),
-  optimizer = "BF", show_progress_bar = FALSE,
-  return_probabilities = TRUE, save_all_perms = TRUE
+  g_BF_prob <- find_MAP(
+    gips(
+      matrix(c(
+        1, 0.5, 0.5,
+        0.5, 1, 0.5,
+        0.5, 0.5, 1
+      ), nrow = 3),
+      number_of_observations,
+      was_mean_estimated = FALSE
+    ),
+    optimizer = "BF", show_progress_bar = FALSE,
+    return_probabilities = TRUE, save_all_perms = TRUE
   )
 
 
@@ -150,6 +160,18 @@ test_that("Properly validate the gips class with no optimization or after a sing
   expect_silent(validate_gips(g_BF_prob))
 
 
+
+  # NaNs or Infs in D_matrix
+  expect_error(gips(
+    S[1:4, 1:4], number_of_observations,
+    was_mean_estimated = FALSE, D_matrix = diag(4) * 1e350
+  ))
+  expect_error(gips(
+    S[1:4, 1:4], number_of_observations,
+    was_mean_estimated = FALSE, D_matrix = diag(Inf, 4)
+  ))
+
+  # Other tests
   g_err <- g2
   class(g_err[[1]]) <- "test"
   expect_error(
@@ -192,14 +214,14 @@ test_that("Properly validate the gips class with no optimization or after a sing
   attr(g_err, "optimization_info")[["non_existing"]] <- "test"
   expect_error(
     validate_gips(g_err),
-    "You have a list of 14 elements."
+    "You have a list of 15 elements."
   )
 
   g_err <- g2
   attr(g_err, "optimization_info")[["acceptance_rate"]] <- NULL
   expect_error(
     validate_gips(g_err),
-    "You have a list of 12 elements."
+    "You have a list of 13 elements."
   )
 
   g_err <- g2
@@ -207,7 +229,7 @@ test_that("Properly validate the gips class with no optimization or after a sing
   attr(g_err, "optimization_info")[["acceptance_rate"]] <- NULL
   expect_error(
     validate_gips(g_err),
-    "You have a list of 13 elements."
+    "You have a list of 14 elements."
   )
   # this one showed an error that one have the list of 13 elements, which is actually expected, but the names of the fields are not expected.
 
@@ -354,6 +376,13 @@ test_that("Properly validate the gips class with no optimization or after a sing
     "must have properties of probability. All elements in range"
   )
 
+  g_good <- g2
+  attr(g_good, "optimization_info")[["post_probabilities"]] <- c(1, rep(0, length(attr(g_good, "optimization_info")[["post_probabilities"]]) - 1)) # this could underflow to 0
+  names(attr(g_good, "optimization_info")[["post_probabilities"]]) <- names(attr(g2, "optimization_info")[["post_probabilities"]])
+  expect_silent(
+    validate_gips(g_good)
+  )
+
   g_err <- g2
   attr(g_err, "optimization_info")[["did_converge"]] <- TRUE
   expect_error(
@@ -467,17 +496,19 @@ test_that("Properly validate the gips class after multiple optimizations", {
   g3 <- find_MAP(g3, max_iter = 3, show_progress_bar = FALSE, optimizer = "HC", return_probabilities = FALSE)
 
   expect_warning(expect_message(expect_message(
-    g_MH_MH <- find_MAP(find_MAP(gips(
-      matrix(c(1, 0.5, 0.5, 5), nrow = 2),
-      number_of_observations,
-      was_mean_estimated = FALSE
-    ),
-    optimizer = "MH", show_progress_bar = FALSE,
-    return_probabilities = FALSE, max_iter = 3
-    ),
-    optimizer = "MH", show_progress_bar = FALSE,
-    return_probabilities = TRUE, save_all_perms = TRUE,
-    max_iter = 3
+    g_MH_MH <- find_MAP(
+      find_MAP(
+        gips(
+          matrix(c(1, 0.5, 0.5, 5), nrow = 2),
+          number_of_observations,
+          was_mean_estimated = FALSE
+        ),
+        optimizer = "MH", show_progress_bar = FALSE,
+        return_probabilities = FALSE, max_iter = 3
+      ),
+      optimizer = "MH", show_progress_bar = FALSE,
+      return_probabilities = TRUE, max_iter = 3,
+      save_all_perms = TRUE
     )
   ))) # 2 messages and a warning
 
@@ -643,7 +674,7 @@ test_that("Process proper parameters", {
   ))
 })
 
-test_that("check_correctness_of_arguments properly validates arguments", {
+test_that("check_correctness_of_arguments() properly validates arguments", {
   expect_silent(check_correctness_of_arguments(
     S, number_of_observations, 30,
     permutations::permutation("(1,3)(2,4)(5,6)"),
@@ -724,15 +755,20 @@ test_that("check_correctness_of_arguments properly validates arguments", {
     permutations::permutation("(1,3)(2,4)(5,6)"),
     NULL, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
   ))
-  expect_error(check_correctness_of_arguments(
+  expect_silent(check_correctness_of_arguments(
     S, number_of_observations, 30,
     permutations::permutation("(1,3)(2,4)(5,6)"),
-    1.9, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
+    1.1, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
   ))
   expect_error(check_correctness_of_arguments(
     S, number_of_observations, 30,
     permutations::permutation("(1,3)(2,4)(5,6)"),
-    2, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
+    0.9, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
+  ))
+  expect_error(check_correctness_of_arguments(
+    S, number_of_observations, 30,
+    permutations::permutation("(1,3)(2,4)(5,6)"),
+    1, diag(nrow = ncol(S)), FALSE, FALSE, FALSE, FALSE
   ))
   expect_error(check_correctness_of_arguments(
     S, number_of_observations, 30,
@@ -801,7 +837,7 @@ test_that("check_correctness_of_arguments properly validates arguments", {
   expect_error(check_correctness_of_arguments(
     S, number_of_observations + 0.1, 1,
     "(1,3)(2,4)(5,6)",
-    2, diag(nrow = ncol(S)), "FALSE", "FALSE", "FALSE", "FALSE"
+    1, diag(nrow = ncol(S)), "FALSE", "FALSE", "FALSE", "FALSE"
   ), "8 problems identified with provided arguments")
 
   # old tests:
@@ -869,7 +905,7 @@ test_that("check_correctness_of_arguments properly validates arguments", {
   ))
   expect_error(check_correctness_of_arguments(matrix_invariant_by_example_perm, number_of_observations,
     max_iter = 10,
-    start_perm = example_perm, delta = 2, D_matrix = NULL,
+    start_perm = example_perm, delta = 1, D_matrix = NULL,
     was_mean_estimated = FALSE, return_probabilities = FALSE,
     save_all_perms = FALSE, show_progress_bar = FALSE
   ))
@@ -941,7 +977,7 @@ test_that("check_correctness_of_arguments properly validates arguments", {
   # A number of problems at the same time. Not all are printed:
   expect_error(check_correctness_of_arguments(matrix_invariant_by_example_perm,
     number_of_observations = -1, max_iter = 1,
-    start_perm = example_perm, delta = 2, D_matrix = 7,
+    start_perm = example_perm, delta = 1, D_matrix = 7,
     was_mean_estimated = NA, return_probabilities = "FALSE",
     save_all_perms = 7, show_progress_bar = NULL
   ), "\\.\\.\\. and 3 more problems")
@@ -949,26 +985,55 @@ test_that("check_correctness_of_arguments properly validates arguments", {
 
 
 test_that("print.gips() works", {
+  expect_identical(
+    convert_log_diff_to_str(1009.5, 3),
+    "2.632e+438"
+  )
+  expect_identical(
+    convert_log_diff_to_str(16.1, 3),
+    "9820670.922"
+  )
+  expect_identical(
+    convert_log_diff_to_str(16.2, 3),
+    "1.085e+7"
+  )
+  expect_identical(
+    convert_log_diff_to_str(-7.677, 3),
+    "4.634e-4"
+  )
+  expect_identical(
+    convert_log_diff_to_str(Inf, 3),
+    "Inf"
+  )
+  expect_identical(
+    convert_log_diff_to_str(-Inf, 3),
+    "-Inf"
+  )
+  expect_identical(
+    convert_log_diff_to_str(0, 3),
+    "1"
+  )
+
   g <- gips(S, number_of_observations, was_mean_estimated = FALSE)
   g_map <- find_MAP(g, 10, show_progress_bar = FALSE, optimizer = "MH")
 
   expect_output(
     print(g),
-    "The permutation \\(\\)\n - is 1 times more likely than the id, \\(\\) permutation"
+    "The permutation \\(\\):\n - is 1 times more likely than the \\(\\) permutation"
   )
   expect_output(
     print(g, log_value = TRUE),
-    "The permutation \\(\\)\n - is 1 times more likely than the id, \\(\\) permutation\n - has log posteriori"
+    "The permutation \\(\\):\n - is 1 times more likely than the \\(\\) permutation;\n - has log posteriori"
   )
   expect_output(
     print(g_map),
-    "\n - was found after 10 log_posteriori calculations\n - is"
+    "\n - was found after 10 posteriori calculations;\n - is"
   )
 
   # oneline:
   expect_output(
     print(g, oneline = TRUE),
-    "The permutation \\(\\); is 1 times more likely"
+    "The permutation \\(\\): is 1 times more likely"
   )
   expect_output(
     print(g, oneline = TRUE, log_value = TRUE),
@@ -976,7 +1041,7 @@ test_that("print.gips() works", {
   )
   expect_output(
     print(g_map, oneline = TRUE),
-    "; was found after 10 log_posteriori calculations; is"
+    ": was found after 10 posteriori calculations; is"
   )
 })
 
@@ -987,12 +1052,15 @@ test_that("plot.gips() works or abords for wrong arguments", {
   )
 
   expect_error(plot.gips(custom_perm1))
-
   expect_error(plot(g1, type = "both"))
+  expect_error(plot(g1, type = c("du", "pa")))
   expect_message(
     plot(g1),
     "`type = NA` was automatically changed to `type = 'heatmap'`"
   )
+  expect_silent(my_ggplot1 <- plot(g1, type = "heatmap"))
+  expect_silent(my_ggplot2 <- plot(g1, type = "MLE"))
+  expect_true(all.equal(my_ggplot1, my_ggplot2)) # cannot use expect_equal(), because it checks for equal enviroments, but in R all enviroments are different even if have the same elements in itself
 
   g1_found <- find_MAP(g1, 3, show_progress_bar = FALSE, optimizer = "MH")
   expect_message(
@@ -1013,7 +1081,15 @@ test_that("plot.gips() works or abords for wrong arguments", {
   )
 })
 
-test_that("get_diagonalized_matrix_for_heatmap works", {
+test_that("plot.gips() works for books example", {
+  Z <- DAAG::oddbooks[, c(1, 2, 3)]
+  Z$height <- Z$height / sqrt(2)
+
+  g <- gips(cov(Z), 7, D_matrix = 1 * diag(3))
+  expect_silent(plot(g, type = "heatmap"))
+})
+
+test_that("get_diagonalized_matrix_for_heatmap() works", {
   custom_perm1 <- gips_perm("(1,2)(3,4,5)(6)", 6)
   g1 <- gips(S, number_of_observations,
     was_mean_estimated = FALSE, perm = custom_perm1
@@ -1029,7 +1105,8 @@ test_that("get_diagonalized_matrix_for_heatmap works", {
 test_that("summary.gips() works", {
   custom_perm1 <- gips_perm("(1,2)(3,4,5,6)", 6)
   g1 <- gips(S, number_of_observations,
-    was_mean_estimated = FALSE, perm = custom_perm1
+    was_mean_estimated = FALSE, perm = custom_perm1,
+    D_matrix = diag(1, 6)
   )
 
   start_permutation_log_posteriori <- log_posteriori_of_gips(g1)
@@ -1045,6 +1122,7 @@ test_that("summary.gips() works", {
     ), size = 6, class = "gips_perm"),
     start_permutation_log_posteriori = start_permutation_log_posteriori,
     times_more_likely_than_id = exp(start_permutation_log_posteriori - log_posteriori_id),
+    log_times_more_likely_than_id = start_permutation_log_posteriori - log_posteriori_id,
     n0 = 2, S_matrix = S, number_of_observations = 13,
     was_mean_estimated = FALSE,
     delta = 3, D_matrix = structure(c(
@@ -1054,14 +1132,29 @@ test_that("summary.gips() works", {
       0, 0, 0, 1, 0, 0,
       0, 0, 0, 0, 1, 0,
       0, 0, 0, 0, 0, 1
-    ), .Dim = c(6L, 6L))
+    ), .Dim = c(6L, 6L)),
+    n_parameters = 7,
+    AIC = AIC(g1),
+    BIC = BIC(g1)
   ), class = "summary.gips")
 
-  expect_identical(summary(g1), my_sum)
+  expect_identical(summary(g1), my_sum) # all in my_sum is calculated by the same functions the summary should use
 
   expect_output(
     print(summary(g1)),
-    "Number of observations is bigger than n0 for this permutaion,\nso "
+    "The number of observations is bigger than n0 for this permutation,\nso "
+  )
+
+  expect_output(
+    print(summary(g1)), "free parameters"
+  )
+
+  expect_output(
+    print(summary(g1)), "AIC"
+  )
+
+  expect_output(
+    print(summary(g1)), "BIC"
   )
 
   g2 <- find_MAP(g1, max_iter = 10, optimizer = "MH", show_progress_bar = FALSE)
@@ -1081,6 +1174,11 @@ test_that("summary.gips() works", {
     "Optimization algorithms:"
   )
 
+  # Optimized with BF; those 3 are computed differently for optimized with BF:
+  g4 <- find_MAP(gips(S[1:4, 1:4], number_of_observations), optimizer = "BF", show_progress_bar = FALSE)
+  expect_true(is.null(summary(g4)[["when_was_best"]]))
+  expect_true(is.null(summary(g4)[["log_posteriori_calls_after_best"]]))
+  expect_s3_class(summary(g4)[["start_permutation"]], "gips_perm")
 
   # proper log_posteriori_calls_after_best:
   # g_fake started in (1,2,3) and then comed to (1,3,2), which had bigger log_posteriori value, but only a little bigger
@@ -1089,6 +1187,7 @@ test_that("summary.gips() works", {
   ), dim = c(3L, 3L)), number_of_observations = 10, delta = 3, D_matrix = structure(c(
     1, 0, 0, 0, 1, 0, 0, 0, 1
   ), dim = c(3L, 3L)), was_mean_estimated = TRUE, optimization_info = list(
+    original_perm = gips_perm("", 3),
     acceptance_rate = 0.333333333333333, log_posteriori_values = c(
       -16.01209771488621000000, -18.9125198086359,
       -16.01209771488621421085
@@ -1132,7 +1231,7 @@ test_that("start_permutation_log_posteriori was calculated correctly", {
   )
 })
 
-test_that("summary.gips returns proper n0 for estimated and unestimated mean", {
+test_that("summary.gips() returns proper n0 for estimated and unestimated mean", {
   g_no_em <- gips(S, number_of_observations, was_mean_estimated = FALSE)
   g_em <- gips(S, number_of_observations, was_mean_estimated = TRUE)
 
@@ -1140,7 +1239,7 @@ test_that("summary.gips returns proper n0 for estimated and unestimated mean", {
   expect_equal(summary.gips(g_em)[["n0"]], ncol(S) + 1) # for estimated mean and perm id, one needs n >= (p + 1)
 })
 
-test_that("summary.gips returns proper Times more likely than identity permutation", {
+test_that("summary.gips() returns proper Times more likely than identity permutation", {
   g_no_em <- gips(S, number_of_observations, was_mean_estimated = FALSE)
   g_em <- gips(S, number_of_observations, was_mean_estimated = TRUE)
 
@@ -1154,7 +1253,23 @@ test_that("summary.gips returns proper Times more likely than identity permutati
   )
 })
 
-test_that("get_probabilities_from_gips works", {
+test_that("print.summary.gips() will properly print BIC and AIC when n < n0", {
+  p <- 6
+  number_of_observations <- 2
+  Z <- MASS::mvrnorm(number_of_observations, mu = mu, Sigma = sigma_matrix) # this place is random
+  S <- (t(Z) %*% Z) / number_of_observations # the theoretical mean is 0
+  
+  g <- gips(S, number_of_observations, perm = "()")
+  expect_silent(my_sum <- summary.gips(g))
+  expect_null(my_sum$AIC)
+  expect_null(my_sum$BIC)
+  
+  expect_output(print(my_sum), "BIC:\n The number of observations is smaller than n0 for this permutation,\n so the gips model based on the found permutation does not exist.")
+  expect_output(print(my_sum), "AIC:\n The number of observations is smaller than n0 for this permutation,\n so the gips model based on the found permutation does not exist.")
+})
+
+
+test_that("get_probabilities_from_gips() works", {
   g <- gips(matrix(c(1, 0.5, 0.5, 1.3), nrow = 2), 13, was_mean_estimated = FALSE)
   g_map <- find_MAP(g,
     optimizer = "BF", show_progress_bar = FALSE,
@@ -1189,9 +1304,13 @@ test_that("get_probabilities_from_gips works", {
     "on the `gips` object that does not have saved probabilities."
   )
   expect_null(out)
+
+  # sorted
+  probs <- get_probabilities_from_gips(g_map)
+  expect_equal(order(probs, decreasing = TRUE), c(1, 2))
 })
 
-test_that("forget_perms works properly", {
+test_that("forget_perms() works properly", {
   g <- gips(S, number_of_observations, was_mean_estimated = FALSE)
   g_map <- find_MAP(g, 10,
     show_progress_bar = FALSE, optimizer = "MH",
@@ -1213,3 +1332,156 @@ test_that("forget_perms works properly", {
     "Provided \\`g\\` is an optimized \\`gips\\` object that already has forgotten all permutations\\."
   )
 })
+
+test_that("logLik.gips() works", {
+  # logLik calculated by hand:
+  Z <- matrix(c(
+    -1, 2, -3, 4,
+    1, -1, 1, 1,
+    -1, 2, 2, 3,
+    2, -3, 2, -3,
+    3, -2, 2, -3
+  ), nrow = 5, byrow = TRUE)
+
+  p <- ncol(Z) # 4
+  n <- nrow(Z) # 5
+
+
+  # ==================
+  # Mean is (0,0,0,0)
+  U <- t(Z) %*% Z
+  perm <- gips_perm("(12)(34)", 4)
+  S <- project_matrix(U, perm) / n
+
+  # logLik from definition:
+  loglikelihoods <- mvtnorm::dmvnorm(
+    Z, rep(0, 4), S, log = TRUE
+  )
+  logLik_definition <- sum(loglikelihoods)
+
+  expect_equal(logLik_definition, -35.2883973048347)
+
+  attr(logLik_definition, "df") <- 6 # 10 - 2 - 2 parameters
+  attr(logLik_definition, "nobs") <- n
+
+  # logLik.gips:
+  expect_equal(
+    logLik(gips(U / n, n, perm = perm, was_mean_estimated = FALSE)),
+    logLik_definition
+  )
+
+
+  # ==================
+  # mean was estimated
+  U <- cov(Z) * (n - 1)
+  perm <- gips_perm("(12)(34)", 4)
+  S <- project_matrix(U, perm) / (n - 1)
+
+  logLik_expected <- structure(-28.8015774226105, df = 6, nobs = 5L)
+
+  # logLik.gips:
+  expect_equal(
+    logLik(gips(U / (n - 1), n, perm = perm, was_mean_estimated = TRUE)),
+    logLik_expected
+  )
+
+
+  # ==================
+  # NUll:
+  U <- t(Z) %*% Z
+  expect_warning(
+    expect_equal(
+      logLik(gips(U / n, 2, perm = perm)), NULL
+    ),
+    class = "likelihood_does_not_exists"
+  )
+
+  # ==================
+  # -Inf:
+  g <- gips(diag(0, 4), n)
+  expect_warning(
+    expect_equal(logLik(g), -Inf),
+    class = "singular_matrix"
+  )
+
+  # ==================
+  # Not -Inf:
+  p <- 150
+  g <- gips(diag(1e-310, p), p * 2)
+  expect_no_warning(logLik(g))
+})
+
+test_that("AIC.gips() works", {
+  Z <- matrix(c(
+    -1, 2, -3, 4,
+    1, -1, 1, 1,
+    -1, 2, 2, 3,
+    2, -3, 2, -3,
+    3, -2, 2, -3
+  ), nrow = 5, byrow = TRUE)
+
+  p <- ncol(Z) # 4
+  n <- nrow(Z) # 5
+
+  g <- gips(t(Z) %*% Z / n, n, perm = "(12)(34)", was_mean_estimated = FALSE)
+
+  expect_equal(AIC(g), 82.5767946096694)
+  expect_equal(BIC(g), 80.233422084274)
+
+  # ==================
+  # NUll
+  S <- t(Z) %*% Z / n
+  g <- gips(S, 2)
+  expect_warning(
+    expect_equal(
+      AIC(g), NULL
+    ),
+    class = "likelihood_does_not_exists"
+  )
+  expect_warning(
+    expect_equal(
+      BIC(g), NULL
+    ),
+    class = "likelihood_does_not_exists"
+  )
+
+  # ==================
+  # Inf
+  g <- gips(diag(0, 4), n)
+  expect_warning(expect_equal(AIC(g), Inf), class = "singular_matrix")
+  expect_warning(expect_equal(BIC(g), Inf), class = "singular_matrix")
+
+  # ==================
+  # Not -Inf:
+  p <- 150
+  g <- gips(diag(1e-310, p), p * 2)
+  expect_no_warning(AIC(g))
+  expect_no_warning(BIC(g))
+})
+
+test_that("as.character.gips() work", {
+  A <- matrix(rnorm(4 * 4), nrow = 4)
+  S <- t(A) %*% A
+  g <- gips(S, 14, perm = "(123)")
+  expect_equal(as.character(g), "(1,2,3)")
+})
+
+
+test_that("print.gips() will show the original perm for BF", {
+  g <- gips(S[1:4,1:4], number_of_observations, perm = "(123)")
+  g_map <- find_MAP(g, optimizer = "BF", show_progress_bar = FALSE)
+  
+  expect_output(print(g_map), "than the \\(1,2,3\\)")
+})
+
+test_that("print.summary.gips() will not compare with original the unoptimized gips that is in id", {
+  g <- gips(S[1:4,1:4], number_of_observations, perm = "(123)")
+  expect_output(print(summary(g)), "Times more likely than identity permutation", fixed = TRUE)
+  
+  g <- gips(S[1:4,1:4], number_of_observations, perm = "()")
+  g_map <- find_MAP(g, optimizer = "BF", show_progress_bar = FALSE)
+  expect_output(print(summary(g_map)), "Times more likely than starting permutation", fixed = TRUE)
+  
+  pattern <- "Log_posteriori:\\s*(-?\\d+\\.\\d+)\\s\\sThe number of observations"
+  expect_output(print(summary(g)), pattern) # The "Times more likely than starting permutation:" is skipped
+})
